@@ -47,19 +47,15 @@ RECORDER_IFACE = "org.gnome.DVB.Recorder"
 CHANNEL_LIST_IFACE = "org.gnome.DVB.ChannelList"
 SCHEDULE_IFACE = "org.gnome.DVB.Schedule"
 
-HAL_MANAGER_IFACE = "org.freedesktop.Hal.Manager"
-HAL_DEVICE_IFACE = "org.freedesktop.Hal.Device"
-HAL_MANAGER_PATH = "/org/freedesktop/Hal/Manager"
-HAL_SERVICE = "org.freedesktop.Hal"
-
 def _default_error_handler_func(e):
     print >> sys.stderr, "Error: "+str(e)
 
 global_error_handler = _default_error_handler_func
 
-def get_adapter_info(adapter):
+def get_adapter_info(adapter, frontend):
     dvbelement = gst.element_factory_make ("dvbsrc", "test_dvbsrc")
     dvbelement.set_property("adapter", int(adapter))
+    dvbelement.set_property("frontend", int(frontend))
     pipeline = gst.Pipeline("")
     pipeline.add(dvbelement)
     pipeline.set_state(gst.STATE_READY)
@@ -82,32 +78,22 @@ def get_adapter_info(adapter):
     pipeline.set_state(gst.STATE_NULL)
     return (success, info)
 
-def get_dvb_devices(reply_handler, error_handler):
-    def find_devices_handler(objects):
-        deviceslist = []
-        for o in objects:
-            proxy = bus.get_object(HAL_SERVICE, o)
-            dev = dbus.Interface(proxy, HAL_DEVICE_IFACE)
+def get_dvb_devices():
+    manager = DVBManagerClient()
+    devices = manager.get_devices()   
 
-            dev_file = dev.GetProperty("linux.device_file")
-        
-            match = re.search("adapter(\d+?)/frontend(\d+?)", dev_file)
-            if match != None:
-                adapter = int(match.group(1))
-                info = {}
-                info["adapter"] = adapter
-                info["frontend"] = int(match.group(2))
-                deviceslist.append(info)
-                
-        reply_handler(deviceslist)
+    deviceslist = []
+    for dev in devices:
+        match = re.search("adapter(\d+?)/frontend(\d+?)", dev["device_file"])
+        if match != None:
+            adapter = int(match.group(1))
+            info = {}
+            info["adapter"] = adapter
+            info["frontend"] = int(match.group(2))
+            deviceslist.append(info)
+            
+    return deviceslist
     
-    bus = dbus.SystemBus()
-    # Get proxy object
-    proxy = bus.get_object(HAL_SERVICE, HAL_MANAGER_PATH)
-    # Apply the correct interace to the proxy object
-    halmanager = dbus.Interface(proxy, HAL_MANAGER_IFACE)
-    objects = halmanager.FindDeviceByCapability("dvb", reply_handler=find_devices_handler, error_handler=error_handler)
-
 class DVBManagerClient(gobject.GObject):
     
     __gsignals__ = {
@@ -172,6 +158,9 @@ class DVBManagerClient(gobject.GObject):
         
     def remove_channel_group(self, group_id, **kwargs):
         return self.manager.RemoveChannelGroup(group_id, **kwargs)
+
+    def get_devices(self, **kwargs):
+        return self.manager.GetDevices()
     
     def on_group_added(self, group_id):
         self.emit("group-added", group_id)
@@ -539,76 +528,4 @@ class DVBScheduleClient(gobject.GObject):
         
     def is_scrambled(self, eid, **kwargs):
         return self.schedule.IsScrambled(eid, **kwargs)
-        
-if __name__ == '__main__':
-    loop = gobject.MainLoop()
-    
-    channelsfile = "/home/sebp/.gstreamer-0.10/dvb-channels.conf"
-    #channelsfile = "/home/sebp/DVB/dvb-s-channels.conf"
-    recdir = "/home/sebp/TV"
-    
-    #a = [586000000, 0, 8, "8k", "2/3", "1/4", "QAM16", 4]
 
-    manager = DVBManagerClient ()
-    #manager.add_device_to_new_group (0, 0, channelsfile, recdir)
-    #manager.add_device_to_existing_group (1, 0, 1)
-    
-    #pro7_sat = [12544000, "horizontal", 22000]
-    
-    #scanner = manager.get_scanner_for_device(0, 0)
-    #scanner.add_scanning_data(pro7_sat)
-    #scanner.run()
-    
-    def device_handler(dev_groups):
-        for dev_group in dev_groups:
-            print "Members", dev_group.get_members()
-        
-            rec = dev_group.get_recorder()
-            timers = rec.get_timers()
-            print timers
-            for tid in timers:
-                print "Start", rec.get_start_time(tid)
-                print "End", rec.get_end_time(tid)
-                print "Duration", rec.get_duration(tid)
-                
-            print rec.get_active_timers()
-            
-            print rec.add_timer(32, 2008, 7, 28, 23, 42, 2)
-                
-            channellist = dev_group.get_channel_list()
-            print "RADIO CHANNELS"
-            for channel_id in channellist.get_radio_channels():
-                print "SID", channel_id
-                print "Name", channellist.get_channel_name(channel_id)
-                print "Network", channellist.get_channel_network(channel_id)
-            print
-            print "TV CHANNELS"
-            for channel_id in channellist.get_tv_channels():
-                print "SID", channel_id
-                print "Name", channellist.get_channel_name(channel_id)
-                print "Network", channellist.get_channel_network(channel_id)
-                print "URL", channellist.get_channel_url(channel_id)
-                schedule = dev_group.get_schedule (channel_id)
-                event_now = schedule.now_playing()
-                print u"Now: %s" % schedule.get_name(event_now)
-                print u"\tDesc: %s" % schedule.get_short_description(event_now)
-                time = schedule.get_local_start_time(event_now)
-                if len(time) == 6:
-                    print u"\tStart: %04d-%02d-%02d %02d:%02d:%02d" % (time[0], time[1], time[2], time[3],
-                        time[4], time[5])
-                print u"\tDuration: %s" % schedule.get_duration(event_now)
-                print
-            
-        recstore = DVBRecordingsStoreClient()
-        for rid in recstore.get_recordings():
-            print "Channel", recstore.get_channel_name(rid)
-            print "Location", recstore.get_location(rid)
-            print "Start", recstore.get_start_time(rid)
-            print recstore.get_start_timestamp(rid)
-            print "Length", recstore.get_length(rid)
-            print "Name", recstore.get_name (rid)
-            print "Desc", recstore.get_description(rid)
-    
-    dev_groups = manager.get_registered_device_groups(reply_handler=device_handler, error_handler=global_error_handler)
-    
-    loop.run()
