@@ -16,6 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
+import datetime
+import gobject
 import gtk
 from gnomedvb import DVBRecordingsStoreClient, global_error_handler
 from cgi import escape
@@ -30,7 +32,7 @@ class RecordingsStore(gtk.ListStore):
     COL_ID,) = range(6)
 
     def __init__(self):
-        gtk.ListStore.__init__(self, int, str, str, int, str, int)
+        gtk.ListStore.__init__(self, gobject.TYPE_PYOBJECT, str, str, int, str, int)
         
         self._recstore = DVBRecordingsStoreClient()
         self._recstore.connect("changed", self._on_changed)
@@ -41,14 +43,17 @@ class RecordingsStore(gtk.ListStore):
         return self._recstore
         
     def _append_recording(self, rec_id):
-        channame = self._recstore.get_channel_name(rec_id)
-        name = escape(self._recstore.get_name(rec_id))
-        start = self._recstore.get_start_timestamp(rec_id)
-        duration = self._recstore.get_length(rec_id)
-        location = self._recstore.get_location(rec_id)
-        #print "Desc", recstore.get_description(rec_id)
+        info, success = self._recstore.get_all_informations (rec_id)
+        
+        if success:
+            channame = info[5]
+            name = escape(info[1])
+            start = datetime.datetime.fromtimestamp(info[4])
+            duration = info[3]
+            location = info[6]
+            #print "Desc", recstore.get_description(rec_id)
     
-        self.append([start, channame, name, duration, location, rec_id])
+            self.append([start, channame, name, duration, location, rec_id])
         
     def _fill(self):
         def append_rec(rids):
