@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
+import glib
 import gnomedvb
 import gtk
 from gettext import gettext as _
@@ -29,6 +30,31 @@ from gnomedvb.ui.wizard.pages.SaveChannelListPage import SaveChannelListPage
 from gnomedvb.ui.wizard.pages.SummaryPage import SummaryPage
 from gnomedvb.ui.wizard.pages.SetupDevicePage import SetupDevicePage
 
+class CloseDialog(gtk.Dialog):
+
+    def __init__(self, parent=None):
+        gtk.Dialog.__init__(self, title="",
+            parent=parent,
+            flags=gtk.DIALOG_DESTROY_WITH_PARENT)
+
+        self.set_border_width(5)
+        self.set_has_separator(False)
+        self.vbox.set_spacing(6)
+
+        label = gtk.Label(_("Cleaning up. This may take a while."))
+        label.show()
+        self.vbox.pack_start(label, False)
+
+        self.progressbar = gtk.ProgressBar()
+        self.progressbar.set_pulse_step(0.1)
+        self._progressbar_timer = glib.timeout_add(100, self._progressbar_pulse)
+        self.progressbar.show()
+        self.vbox.pack_start(self.progressbar, False)
+            
+    def _progressbar_pulse(self):
+        self.progressbar.pulse()
+        return True
+
 class SetupWizard(gtk.Assistant):
 
     (INTRO_PAGE,
@@ -53,7 +79,6 @@ class SetupWizard(gtk.Assistant):
         self.connect ('prepare', self.on_prepare)
         self.set_forward_page_func(self.page_func)
         self.set_default_size(500, 400)
-        self.set_border_width(4)
         self.set_title(_("Setup digital TV"))
         
         self.intro_page = IntroPage()
@@ -85,6 +110,18 @@ class SetupWizard(gtk.Assistant):
         self.summary_page.configure_button.connect("clicked",
             lambda button: self.set_current_page(self.INTRO_PAGE))
         self.append_page(self.summary_page)
+
+        icon_theme = gtk.icon_theme_get_default()
+        width, height = gtk.icon_size_lookup(gtk.ICON_SIZE_DIALOG)
+        try:
+            pixbuf = icon_theme.load_icon("gnome-dvb-setup", height, 0)
+            for i in range(self.get_n_pages()):
+                page = self.get_nth_page(i)
+                self.set_page_header_image(page, pixbuf)
+        except glib.GError:
+            pass
+
+        gtk.window_set_default_icon_name("gnome-dvb-setup")
         
     def append_page(self, page):
         gtk.Assistant.append_page(self, page)
@@ -117,6 +154,7 @@ class SetupWizard(gtk.Assistant):
             self.__ask_on_exit = False
             if self.__expert_mode:
                 summary = _('The generated channels file can be used to configure your devices in the control center.')
+                success = True
             else:
                 success, summary = self.setup_page.get_summary()
             page.set_device_name_and_details(self.__adapter_info["name"],
@@ -166,16 +204,22 @@ class SetupWizard(gtk.Assistant):
             
             response = dialog.run()
             if response == gtk.RESPONSE_YES:
-                if scanner != None:
-                    scanner.destroy()
-                gtk.main_quit()
-            elif response == gtk.RESPONSE_NO:
                 dialog.destroy()
-        
+                self.destroy_scanner(scanner)
+            else:
+                dialog.destroy()
+
             return True
         else:
-            if scanner != None:
-                scanner.destroy()
+            self.destroy_scanner(scanner)
+
+    def destroy_scanner(self, scanner):
+        if scanner != None:
+            scanner.destroy(reply_handler=gtk.main_quit,
+                error_handler=gnomedvb.global_error_handler)
+            close_dialog = CloseDialog(self)
+            close_dialog.show()
+        else:
             gtk.main_quit()
             
     def on_next_page(self, adapters_page):
