@@ -19,8 +19,10 @@
 import gnomedvb
 import gtk
 import gobject
+import glib
 from gettext import gettext as _
 from gnomedvb.ui.wizard.pages.BasePage import BasePage
+from gnomedvb.ui.widgets.Frame import TextFieldLabel
 from gnomedvb import global_error_handler
 
 class ChannelScanPage(BasePage):
@@ -49,13 +51,16 @@ class ChannelScanPage(BasePage):
         self._max_freqs = 0
         self._scanned_freqs = 0
         self._last_qsize = 0
+        self._progressbar_timer = 0
         
         self.set_spacing(12)
         self._theme = gtk.icon_theme_get_default()
-        
-        self._label.set_markup (
-            _("Choose the channels you want to have in your list of channels. You can reorder the channels, too.")
+
+        text = "%s\n%s" % (
+            _("This process can take some time."),
+            _("You can select the channels you want to have in your list of channels.")
         )
+        self._label.set_markup (text)
         
         actiongroup = gtk.ActionGroup('channels')
         actiongroup.add_actions([
@@ -73,6 +78,11 @@ class ChannelScanPage(BasePage):
 
         topbox = gtk.VBox(spacing=6)
         self.pack_start(topbox)
+
+        ali = TextFieldLabel()
+        label = ali.get_label()
+        label.set_markup_with_mnemonic(_("_Channels:"))
+        topbox.pack_start(ali, False)
         
         # Logo, Name, active, SID, scrambled
         self.tvchannels = gtk.ListStore(gtk.gdk.Pixbuf, str, bool, int, bool)
@@ -80,6 +90,8 @@ class ChannelScanPage(BasePage):
         self.tvchannelsview.connect("button-press-event",
             self.__on_treeview_button_press_event)
         self.tvchannelsview.set_reorderable(True)
+        self.tvchannelsview.set_headers_visible(False)
+        label.set_mnemonic_widget(self.tvchannelsview)
         
         col_name = gtk.TreeViewColumn(_("Channel"))
         
@@ -104,7 +116,7 @@ class ChannelScanPage(BasePage):
         
         topbox.pack_start(scrolledtvview)
 
-        self.scrambledbutton = gtk.CheckButton(_("Select scrambled channels"))
+        self.scrambledbutton = gtk.CheckButton(_("Select _scrambled channels"))
         self.scrambledbutton.set_active(True)
         self.scrambledbutton.connect("toggled", self.__on_select_encrypted_toggled)
         topbox.pack_start(self.scrambledbutton, False)
@@ -117,10 +129,7 @@ class ChannelScanPage(BasePage):
         
     def get_page_title(self):
         return _("Scanning for channels")
-        
-    def get_page_type(self):
-        return gtk.ASSISTANT_PAGE_PROGRESS
-        
+   
     def get_selected_channel_sids(self):
         return [row[self.COL_SID] for row in self.tvchannels if row[self.COL_ACTIVE]]
         
@@ -137,6 +146,8 @@ class ChannelScanPage(BasePage):
         self._scanner.connect ("channel-added", self.__on_channel_added)
         self._scanner.connect ("finished", self.__on_finished)
 
+        self.progressbar.set_pulse_step(0.1)
+        self._progressbar_timer = glib.timeout_add(100, self._progressbar_pulse)
         self.progressbar.show()
 
         if isinstance(tuning_data, str):
@@ -148,6 +159,10 @@ class ChannelScanPage(BasePage):
             self._scanner.run()
         else:
             self._scanner.destroy()
+            
+    def _progressbar_pulse(self):
+        self.progressbar.pulse()
+        return True
         
     def __on_channel_added(self, scanner, freq, sid, name, network, channeltype, scrambled):
         try:
@@ -161,7 +176,7 @@ class ChannelScanPage(BasePage):
                 elif channeltype == "Radio":
                     icon = self._theme.load_icon("audio-x-generic", 16,
                         gtk.ICON_LOOKUP_USE_BUILTIN)
-        except gobject.GError:
+        except glib.GError:
             icon = None
         
         name = name.replace("&", "&amp;")
@@ -181,6 +196,11 @@ class ChannelScanPage(BasePage):
             self._max_freqs += qsize - self._last_qsize + 1
         self._scanned_freqs += 1
         fraction = float(self._scanned_freqs) / self._max_freqs
+        # Stop progressbar from pulsing
+        if self._progressbar_timer > 0:
+            glib.source_remove(self._progressbar_timer)
+            self._progressbar_timer = 0
+
         self.progressbar.set_fraction(fraction)
         self._last_qsize = qsize
         
